function [ Laplacepsi ] = Laplace1s(x,y,z,xi,yi,zi,Z,a0  )
%
% This function calculates the Laplace Operation on the 1s Atomic orbital
%
% function [ Laplacepsi ] = Laplace1s(x,y,z,xi,yi,zi,Z,a0 )
%
% Laplacepsi       	result of the Laplace transformation
% x                 values for the x-direction
% y                 values for the y-direction
% z                 values for the z-direction
% xi                values for the 
% yi                values for the 
% zi                values for the 
% Z                 Atomic number 
% a0                Bohr radius



%% Define r
% r is the radius and can be calculated with the definition of spherical
% coordinates

r = sqrt((x-xi)^2+(y-yi)^2+(z-zi)^2);

%% Result
%
% The formular for the Laplacian transformation has been calculated by hand

Laplacepsi = sqrt(Z^5/(pi*a0^5)).*(Z/a0-2./r).*exp(-Z*r/a0);


end


